@@ -710,12 +710,28 @@ pref("network.IDN.whitelist.tw", true);
 pref("network.IDN.whitelist.vn", true);
 
 // IDN ccTLDs
-// sa, Saudi Arabia, .<al-Saudiah>
-pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true); 
-// ru, Russian Federation, .<RF>
-pref("network.IDN.whitelist.xn--p1ai", true);
+// ae, UAE, .<Emarat>
+pref("network.IDN.whitelist.xn--mgbaam7a8h", true); 
+// cn, China, .<China> with variants
+pref("network.IDN.whitelist.xn--fiqz9s", true); // Traditional
+pref("network.IDN.whitelist.xn--fiqs8s", true); // Simplified
+// hk, Hong Kong, .<Hong Kong>
+pref("network.IDN.whitelist.xn--j6w193g", true);
+// ir, Iran, <.Iran> with variants
+pref("network.IDN.whitelist.xn--mgba3a4f16a", true);
+pref("network.IDN.whitelist.xn--mgba3a4fra", true);
 // jo, Jordan, .<Al-Ordon>
 pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
+// ru, Russian Federation, .<RF>
+pref("network.IDN.whitelist.xn--p1ai", true);
+// sa, Saudi Arabia, .<al-Saudiah> with variants
+pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true); 
+pref("network.IDN.whitelist.xn--mgberp4a5d4a87g", true);
+pref("network.IDN.whitelist.xn--mgbqly7c0a67fbc", true);
+pref("network.IDN.whitelist.xn--mgbqly7cvafr", true);
+// tw, Taiwan, <.Taiwan> with variants
+pref("network.IDN.whitelist.xn--kpry57d", true);  // Traditional
+pref("network.IDN.whitelist.xn--kprw13d", true);  // Simplified
 
 // gTLDs
 pref("network.IDN.whitelist.biz", true);
@@ -803,7 +819,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 826 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 842 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -822,9 +838,9 @@ pref("network.ntlm.send-lm-response", false);
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 851 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 867 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  0);
-//@line 853 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 869 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -1186,9 +1202,9 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1593 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1609 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 1595 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1611 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 // Mac specific preference defaults
 pref("browser.drag_out_of_frame_style", 1);
 pref("ui.key.saveLink.shift", false); // true = shift, false = meta
@@ -1602,21 +1618,21 @@ pref("print.print_extra_margin", 90); // twips (90 twips is an eigth of an inch)
 // See bug 404131, topmost <panel> element wins to Dashboard on MacOSX.
 pref("ui.panel.default_level_parent", false);
 
-//@line 2010 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2026 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2211 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2227 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2305 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2321 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2578 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2594 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2646 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2662 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2672 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2688 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2692 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2708 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2700 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2716 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1640,7 +1656,7 @@ pref("image.cache.size", 5242880);
 // Size is given a weight of 1000 - timeweight.
 pref("image.cache.timeweight", 500);
 
-//@line 2729 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2745 "/builds/slave/mozilla-1.9.1-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
